ollama.cli.chat

High-level client for Ollama's /api/chat endpoint.

High-level client for Ollama's `/api/chat` endpoint.
raw docstring

ollama.cli.config

Runtime configuration for the Ollama endpoint used by this library.

Runtime configuration for the Ollama endpoint used by this library.
raw docstring

ollama.cli.core

Shared request helpers used by the public API namespaces.

Shared request helpers used by the public API namespaces.
raw docstring

ollama.cli.embed

High-level client for Ollama's /api/embed endpoint.

High-level client for Ollama's `/api/embed` endpoint.
raw docstring

ollama.cli.generate

High-level client for Ollama's /api/generate endpoint.

High-level client for Ollama's `/api/generate` endpoint.
raw docstring

ollama.cli.schemas

Specs describing request and response payloads used by the public API.

Specs describing request and response payloads used by the public API.
raw docstring

No vars found in this namespace.

cljdoc builds & hosts documentation for Clojure/Script libraries