Clojure only.

ollama.cli.chat

High-level client for Ollama's /api/chat endpoint.

High-level client for Ollama's `/api/chat` endpoint.
raw docstring

chatclj

(chat request)

Send a chat request to Ollama.

request accepts the keys defined by ollama.cli.schemas/chat-request, including :model, :messages, optional :tools, and optional generation options.

Returns a lazy sequence of parsed stream events when streaming is enabled, or a single parsed response map when streaming is disabled.

Send a chat request to Ollama.

`request` accepts the keys defined by `ollama.cli.schemas/chat-request`,
including `:model`, `:messages`, optional `:tools`, and optional generation
options.

Returns a lazy sequence of parsed stream events when streaming is enabled, or
a single parsed response map when streaming is disabled.
sourceraw docstring

headersclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries