ollama.cli.config

Runtime configuration for the Ollama endpoint used by this library.

Runtime configuration for the Ollama endpoint used by this library.
raw docstring

all-configclj

(all-config)

Return the current runtime configuration map.

Return the current runtime configuration map.
sourceraw docstring

configclj

source

config!clj

(config! new-config)

Replace the current runtime configuration map.

Replace the current runtime configuration map.
sourceraw docstring

hostclj

(host)

Return the configured Ollama host.

Return the configured Ollama host.
sourceraw docstring

portclj

(port)

Return the configured Ollama port.

Return the configured Ollama port.
sourceraw docstring

reset-config!clj

(reset-config!)

Reset runtime configuration to the defaults from resources/config.edn.

Reset runtime configuration to the defaults from `resources/config.edn`.
sourceraw docstring

urlclj

(url)

Return the base URL used for Ollama API requests.

Return the base URL used for Ollama API requests.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries