Clojure only.

ollama.cli.embed

High-level client for Ollama's /api/embed endpoint.

High-level client for Ollama's `/api/embed` endpoint.
raw docstring

embedclj

(embed request)

Request embeddings from Ollama.

request accepts the keys defined by ollama.cli.schemas/embed-request, including :model, :input, and optional :dimensions or :options.

Returns a parsed response map with model metadata and embedding vectors.

Request embeddings from Ollama.

`request` accepts the keys defined by `ollama.cli.schemas/embed-request`,
including `:model`, `:input`, and optional `:dimensions` or `:options`.

Returns a parsed response map with model metadata and embedding vectors.
sourceraw docstring

headersclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries