High-level client for Ollama's /api/chat endpoint.
High-level client for Ollama's `/api/chat` endpoint.
Runtime configuration for the Ollama endpoint used by this library.
Runtime configuration for the Ollama endpoint used by this library.
Shared request helpers used by the public API namespaces.
Shared request helpers used by the public API namespaces.
High-level client for Ollama's /api/embed endpoint.
High-level client for Ollama's `/api/embed` endpoint.
High-level client for Ollama's /api/generate endpoint.
High-level client for Ollama's `/api/generate` endpoint.
Specs describing request and response payloads used by the public API.
Specs describing request and response payloads used by the public API.
No vars found in this namespace.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |