Runtime configuration for the Ollama endpoint used by this library.
Runtime configuration for the Ollama endpoint used by this library.
(all-config)Return the current runtime configuration map.
Return the current runtime configuration map.
(config! new-config)Replace the current runtime configuration map.
Replace the current runtime configuration map.
(host)Return the configured Ollama host.
Return the configured Ollama host.
(port)Return the configured Ollama port.
Return the configured Ollama port.
(reset-config!)Reset runtime configuration to the defaults from resources/config.edn.
Reset runtime configuration to the defaults from `resources/config.edn`.
(url)Return the base URL used for Ollama API requests.
Return the base URL used for Ollama API requests.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |