High-level client for Ollama's /api/embed endpoint.
High-level client for Ollama's `/api/embed` endpoint.
(embed request)Request embeddings from Ollama.
request accepts the keys defined by ollama.cli.schemas/embed-request,
including :model, :input, and optional :dimensions or :options.
Returns a parsed response map with model metadata and embedding vectors.
Request embeddings from Ollama. `request` accepts the keys defined by `ollama.cli.schemas/embed-request`, including `:model`, `:input`, and optional `:dimensions` or `:options`. Returns a parsed response map with model metadata and embedding vectors.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |